@@ -4,7 +4,12 @@ HTML::Microformats::RELBASE - base rel-* microformat class
 
 =head1 SYNOPSIS
 
-TODO
+ my @tags = HTML::Microformats::RelTag->extract_all(
+                   $doc->documentElement, $context);
+ foreach my $tag (@tags)
+ {
+   print $tag->get_href . "\n";
+ }
 
 =head1 DESCRIPTION
 
@@ -42,7 +47,7 @@ use 5.008;
 
 use HTML::Microformats::_util qw(stringify);
 
-our $VERSION = '0.00_12';
+our $VERSION = '0.00_13';
 
 sub new
 {
